summaryrefslogtreecommitdiff
path: root/gcc/config/v850
diff options
context:
space:
mode:
authorkazu <kazu@138bc75d-0d04-0410-961f-82ee72b054a4>2002-09-18 11:43:45 +0000
committerkazu <kazu@138bc75d-0d04-0410-961f-82ee72b054a4>2002-09-18 11:43:45 +0000
commit808a491c397ca7051a634a0465bef7061d7a4d78 (patch)
treedbbc439fc42504750f53ed2a6d46af05dd6eee4d /gcc/config/v850
parentc39848bcc6d3f2d79f20f6b73c91884b0894c16e (diff)
downloadgcc-808a491c397ca7051a634a0465bef7061d7a4d78.tar.gz
* config/s390/s390.c: Follow spelling convention.
* config/sh/lib1funcs.asm: Likewise. * config/sh/sh.c: Likewise. * config/sh/sh.h: Likewise. * config/sparc/sparc.c: Likewise. * config/sparc/sparc.h: Likewise. * config/sparc/sparc.md: Likewise. * config/stormy16/stormy16.c: Likewise. * config/stormy16/stormy16.h: Likewise. * config/v850/v850.c: Likewise. * config/v850/v850.h: Likewise. * config/vax/vax.c: Likewise. * config/vax/vax.h: Likewise. git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@57276 138bc75d-0d04-0410-961f-82ee72b054a4
Diffstat (limited to 'gcc/config/v850')
-rw-r--r--gcc/config/v850/v850.c8
-rw-r--r--gcc/config/v850/v850.h4
2 files changed, 6 insertions, 6 deletions
diff --git a/gcc/config/v850/v850.c b/gcc/config/v850/v850.c
index d0bdff52dbc..b14ff1a3fc2 100644
--- a/gcc/config/v850/v850.c
+++ b/gcc/config/v850/v850.c
@@ -2368,7 +2368,7 @@ register_is_ok_for_epilogue (op, mode)
&& (((REGNO (op) >= 20) && REGNO (op) <= 31)));
}
-/* Return non-zero if the given RTX is suitable for collapsing into
+/* Return nonzero if the given RTX is suitable for collapsing into
jump to a function epilogue. */
int
pattern_is_ok_for_epilogue (op, mode)
@@ -2547,7 +2547,7 @@ construct_restore_jr (op)
}
-/* Return non-zero if the given RTX is suitable for collapsing into
+/* Return nonzero if the given RTX is suitable for collapsing into
a jump to a function prologue. */
int
pattern_is_ok_for_prologue (op, mode)
@@ -2947,7 +2947,7 @@ v850_insert_attributes (decl, attr_ptr)
}
}
-/* Return non-zero if the given RTX is suitable
+/* Return nonzero if the given RTX is suitable
for collapsing into a DISPOSE instruction. */
int
@@ -3137,7 +3137,7 @@ construct_dispose_instruction (op)
return buff;
}
-/* Return non-zero if the given RTX is suitable
+/* Return nonzero if the given RTX is suitable
for collapsing into a PREPARE instruction. */
int
diff --git a/gcc/config/v850/v850.h b/gcc/config/v850/v850.h
index e1c33f39937..9d5200b9a75 100644
--- a/gcc/config/v850/v850.h
+++ b/gcc/config/v850/v850.h
@@ -249,7 +249,7 @@ extern struct small_memory_info small_memory[(int)SMALL_MEMORY_max];
LEVEL is the optimization level specified; 2 if `-O2' is
specified, 1 if `-O' is specified, and 0 if neither is specified.
- SIZE is non-zero if `-Os' is specified, 0 otherwise.
+ SIZE is nonzero if `-Os' is specified, 0 otherwise.
You should not use this macro to change options that are not
machine-specific. These should uniformly selected by the same
@@ -664,7 +664,7 @@ enum reg_class
{ ARG_POINTER_REGNUM, STACK_POINTER_REGNUM }, \
{ ARG_POINTER_REGNUM, HARD_FRAME_POINTER_REGNUM }} \
/* A C expression that returns non-zero if the compiler is allowed to
try to replace register number FROM-REG with register number
TO-REG. This macro need only be defined if `ELIMINABLE_REGS' is
defined, and will usually be the constant 1, since most of the
@@ -664,7 +664,7 @@ enum reg_class
{ ARG_POINTER_REGNUM, STACK_POINTER_REGNUM }, \
{ ARG_POINTER_REGNUM, HARD_FRAME_POINTER_REGNUM }} \
-/* A C expression that returns non-zero if the compiler is allowed to
+/* A C expression that returns nonzero if the compiler is allowed to
try to replace register number FROM-REG with register number
TO-REG. This macro need only be defined if `ELIMINABLE_REGS' is